=================
XAS data pipeline
=================

.. image:: https://img.shields.io/travis/zhul9311/xas-data-pipeline.svg
        :target: https://travis-ci.org/zhul9311/xas-data-pipeline

.. image:: https://img.shields.io/pypi/v/xas-data-pipeline.svg
        :target: https://pypi.python.org/pypi/xas-data-pipeline


A data pipeline for processing XAS data

* Free software: 3-clause BSD license
* Documentation: (COMING SOON!) https://zhul9311.github.io/xas-data-pipeline.

Features
--------

* TODO
